﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/guardduty/GuardDuty_EXPORTS.h>
#include <aws/guardduty/GuardDutyRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/guardduty/model/ScanResourceCriteria.h>
#include <aws/guardduty/model/EbsSnapshotPreservation.h>
#include <utility>

namespace Aws
{
namespace GuardDuty
{
namespace Model
{

  /**
   */
  class UpdateMalwareScanSettingsRequest : public GuardDutyRequest
  {
  public:
    AWS_GUARDDUTY_API UpdateMalwareScanSettingsRequest() = default;

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "UpdateMalwareScanSettings"; }

    AWS_GUARDDUTY_API Aws::String SerializePayload() const override;


    ///@{
    /**
     * <p>The unique ID of the detector that specifies the GuardDuty service where you
     * want to update scan settings.</p> <p>To find the <code>detectorId</code> in the
     * current Region, see the Settings page in the GuardDuty console, or run the <a
     * href="https://docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html">ListDetectors</a>
     * API.</p>
     */
    inline const Aws::String& GetDetectorId() const { return m_detectorId; }
    inline bool DetectorIdHasBeenSet() const { return m_detectorIdHasBeenSet; }
    template<typename DetectorIdT = Aws::String>
    void SetDetectorId(DetectorIdT&& value) { m_detectorIdHasBeenSet = true; m_detectorId = std::forward<DetectorIdT>(value); }
    template<typename DetectorIdT = Aws::String>
    UpdateMalwareScanSettingsRequest& WithDetectorId(DetectorIdT&& value) { SetDetectorId(std::forward<DetectorIdT>(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>Represents the criteria to be used in the filter for selecting resources to
     * scan.</p>
     */
    inline const ScanResourceCriteria& GetScanResourceCriteria() const { return m_scanResourceCriteria; }
    inline bool ScanResourceCriteriaHasBeenSet() const { return m_scanResourceCriteriaHasBeenSet; }
    template<typename ScanResourceCriteriaT = ScanResourceCriteria>
    void SetScanResourceCriteria(ScanResourceCriteriaT&& value) { m_scanResourceCriteriaHasBeenSet = true; m_scanResourceCriteria = std::forward<ScanResourceCriteriaT>(value); }
    template<typename ScanResourceCriteriaT = ScanResourceCriteria>
    UpdateMalwareScanSettingsRequest& WithScanResourceCriteria(ScanResourceCriteriaT&& value) { SetScanResourceCriteria(std::forward<ScanResourceCriteriaT>(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>An enum value representing possible snapshot preservation settings.</p>
     */
    inline EbsSnapshotPreservation GetEbsSnapshotPreservation() const { return m_ebsSnapshotPreservation; }
    inline bool EbsSnapshotPreservationHasBeenSet() const { return m_ebsSnapshotPreservationHasBeenSet; }
    inline void SetEbsSnapshotPreservation(EbsSnapshotPreservation value) { m_ebsSnapshotPreservationHasBeenSet = true; m_ebsSnapshotPreservation = value; }
    inline UpdateMalwareScanSettingsRequest& WithEbsSnapshotPreservation(EbsSnapshotPreservation value) { SetEbsSnapshotPreservation(value); return *this;}
    ///@}
  private:

    Aws::String m_detectorId;
    bool m_detectorIdHasBeenSet = false;

    ScanResourceCriteria m_scanResourceCriteria;
    bool m_scanResourceCriteriaHasBeenSet = false;

    EbsSnapshotPreservation m_ebsSnapshotPreservation{EbsSnapshotPreservation::NOT_SET};
    bool m_ebsSnapshotPreservationHasBeenSet = false;
  };

} // namespace Model
} // namespace GuardDuty
} // namespace Aws
